==> jc-1.4.0.tar.gz: soot/dava/internal/SET/SETSwitchNode.h <==
// public class soot.dava.internal.SET.SETSwitchNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 4b4d9e8de57cda84 soot_dava_internal_SET_SETSwitchNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETDagNode

#include "soot/dava/internal/SET/SETDagNode.h"

#ifndef _JC_soot_dava_internal_SET_SETSwitchNode_H_
#define _JC_soot_dava_internal_SET_SETSwitchNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs	_jc_soot_dava_internal_SET_SETSwitchNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$refs	_jc_soot_dava_internal_SET_SETSwitchNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$nonrefs	_jc_soot_dava_internal_SET_SETSwitchNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$object	_jc_soot_dava_internal_SET_SETSwitchNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vmethods	_jc_soot_dava_internal_SET_SETSwitchNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vtable	_jc_soot_dava_internal_SET_SETSwitchNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vtype	_jc_soot_dava_internal_SET_SETSwitchNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETSwitchNode$method$_init$0eedf5f8550a6a7a(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_object *, struct _jc_soot_util_IterableSet$object *, struct _jc_object *, struct _jc_soot_util_IterableSet$object *);

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETSwitchNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *);
};

// Vtable
struct _jc_soot_dava_internal_SET_SETSwitchNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
	_jc_soot_dava_internal_SET_SETSwitchNode$vmethods	soot_dava_internal_SET_SETSwitchNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETSwitchNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETSwitchNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs {
	struct _jc_object	*switchNodeList;
	struct _jc_object	*key;
	struct _jc_soot_util_IterableSet$object	*junkBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETSwitchNode$refs {
    _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs	soot_dava_internal_SET_SETSwitchNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETSwitchNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs	soot_dava_internal_SET_SETSwitchNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETSwitchNode$object {
	_jc_soot_dava_internal_SET_SETSwitchNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETSwitchNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETSwitchNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETSwitchNode$vtype _jc_soot_dava_internal_SET_SETSwitchNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETSwitchNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETSwitchNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETSwitchNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/SET/SETSwitchNode.h <==
// public class soot.dava.internal.SET.SETSwitchNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5fe8043c911a8f07 soot_dava_internal_SET_SETControlFlowNode
// @dep_class 1df4134650bc1e83 soot_dava_internal_SET_SETDagNode
// @dep_class 4d3d060182af30b5 soot_dava_internal_SET_SETNode
// @dep_class 4b4d9e8de57cda84 soot_dava_internal_SET_SETSwitchNode

// header file dependencies
// @dep_header soot_dava_internal_SET_SETDagNode

#include "soot/dava/internal/SET/SETDagNode.h"

#ifndef _JC_soot_dava_internal_SET_SETSwitchNode_H_
#define _JC_soot_dava_internal_SET_SETSwitchNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_List$object;
struct _jc_soot_Value$object;
struct _jc_soot_dava_internal_AST_ASTNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmt$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs	_jc_soot_dava_internal_SET_SETSwitchNode$sub_refs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs	_jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$refs	_jc_soot_dava_internal_SET_SETSwitchNode$refs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$nonrefs	_jc_soot_dava_internal_SET_SETSwitchNode$nonrefs;
typedef struct _jc_soot_dava_internal_SET_SETSwitchNode$object	_jc_soot_dava_internal_SET_SETSwitchNode$object;

typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vmethods	_jc_soot_dava_internal_SET_SETSwitchNode$vmethods;
typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vtable	_jc_soot_dava_internal_SET_SETSwitchNode$vtable;
typedef const struct _jc_soot_dava_internal_SET_SETSwitchNode$vtype	_jc_soot_dava_internal_SET_SETSwitchNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_SET_SETSwitchNode$method$_init$0eedf5f8550a6a7a(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *, struct _jc_soot_dava_internal_asg_AugmentedStmt$object *, struct _jc_object *, struct _jc_soot_util_IterableSet$object *, struct _jc_object *, struct _jc_soot_util_IterableSet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_dava_internal_AST_ASTNode$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$emit__5fAST$9abd6bb299fe14c5(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_dava_internal_asg_AugmentedStmt$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$get__5fEntryStmt$d3b7a698292e24c9(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_util_IterableSet$object *_jc_soot_dava_internal_SET_SETSwitchNode$method$get__5fNaturalExits$93615053d2db173e(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$emit__5fAST$9abd6bb299fe14c5;
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$get__5fEntryStmt$d3b7a698292e24c9;
extern _jc_method _jc_soot_dava_internal_SET_SETSwitchNode$method_info$get__5fNaturalExits$93615053d2db173e;

// Virtual methods structure
struct _jc_soot_dava_internal_SET_SETSwitchNode$vmethods {
	struct _jc_soot_dava_internal_AST_ASTNode$object	*(*emit__5fAST$9abd6bb299fe14c5)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_dava_internal_asg_AugmentedStmt$object	*(*get__5fEntryStmt$d3b7a698292e24c9)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_util_IterableSet$object	*(*get__5fNaturalExits$93615053d2db173e)(_jc_env *, struct _jc_soot_dava_internal_SET_SETSwitchNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_SET_SETSwitchNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_internal_SET_SETNode$vmethods	soot_dava_internal_SET_SETNode;
	_jc_soot_dava_internal_SET_SETControlFlowNode$vmethods	soot_dava_internal_SET_SETControlFlowNode;
	_jc_soot_dava_internal_SET_SETDagNode$vmethods	soot_dava_internal_SET_SETDagNode;
	_jc_soot_dava_internal_SET_SETSwitchNode$vmethods	soot_dava_internal_SET_SETSwitchNode;
};

// Vtype
struct _jc_soot_dava_internal_SET_SETSwitchNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_SET_SETSwitchNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs {
	struct _jc_object	*switchNodeList;
	struct _jc_object	*key;
	struct _jc_soot_util_IterableSet$object	*junkBody;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETSwitchNode$refs {
    _jc_soot_dava_internal_SET_SETSwitchNode$sub_refs	soot_dava_internal_SET_SETSwitchNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_refs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_refs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETNode$sub_refs	soot_dava_internal_SET_SETNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_SET_SETSwitchNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_internal_SET_SETNode$sub_nonrefs	soot_dava_internal_SET_SETNode;
    _jc_soot_dava_internal_SET_SETControlFlowNode$sub_nonrefs	soot_dava_internal_SET_SETControlFlowNode;
    _jc_soot_dava_internal_SET_SETDagNode$sub_nonrefs	soot_dava_internal_SET_SETDagNode;
    _jc_soot_dava_internal_SET_SETSwitchNode$sub_nonrefs	soot_dava_internal_SET_SETSwitchNode;
};

// Object instance structure
struct _jc_soot_dava_internal_SET_SETSwitchNode$object {
	_jc_soot_dava_internal_SET_SETSwitchNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_SET_SETSwitchNode$vtype	*vtype;
	_jc_soot_dava_internal_SET_SETSwitchNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_SET_SETSwitchNode$vtype _jc_soot_dava_internal_SET_SETSwitchNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_SET_SETSwitchNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_SET_SETSwitchNode$class_object;

#endif	/* _JC_soot_dava_internal_SET_SETSwitchNode_H_ */
